@@ -1,7 +1,5 @@
 /* messages.c - error reporter -
-   Copyright 1987, 1991, 1992, 1993, 1994, 1995, 1996, 1998, 2000, 2001,
-   2003, 2004, 2005, 2006, 2007, 2008
-   Free Software Foundation, Inc.
+   Copyright (C) 1987-2017 Free Software Foundation, Inc.
    This file is part of GAS, the GNU Assembler.
 
    GAS is free software; you can redistribute it and/or modify
@@ -20,11 +18,19 @@
    02110-1301, USA.  */
 
 #include "as.h"
+#include <signal.h>
 
-static void identify (char *);
+/* If the system doesn't provide strsignal, we get it defined in
+   libiberty but no declaration is supplied.  Because, reasons. */
+#if !defined (HAVE_STRSIGNAL) && !defined (strsignal)
+extern const char *strsignal (int);
+#endif
+
+static void identify (const char *);
 static void as_show_where (void);
-static void as_warn_internal (char *, unsigned int, char *);
-static void as_bad_internal (char *, unsigned int, char *);
+static void as_warn_internal (const char *, unsigned int, char *);
+static void as_bad_internal (const char *, unsigned int, char *);
+static void signal_crash (int) ATTRIBUTE_NORETURN;
 
 /* Despite the rest of the comments in this file, (FIXME-SOON),
    here is the current scheme for error messages etc:
@@ -60,10 +66,13 @@ static void as_bad_internal (char *, unsigned int, char *);
    as_tsktsk() is used when we see a minor error for which
    our error recovery action is almost certainly correct.
    In this case, we print a message and then assembly
-   continues as though no error occurred.  */
+   continues as though no error occurred.
+
+   as_abort () is used for logic failure (assert or abort, signal).
+*/
 
 static void
-identify (char *file)
+identify (const char *file)
 {
   static int identified;
 
@@ -74,7 +83,7 @@ identify (char *file)
   if (!file)
     {
       unsigned int x;
-      as_where (&file, &x);
+      file = as_where (&x);
     }
 
   if (file)
@@ -107,13 +116,18 @@ had_errors (void)
 static void
 as_show_where (void)
 {
-  char *file;
+  const char *file;
   unsigned int line;
 
-  as_where (&file, &line);
+  file = as_where (&line);
   identify (file);
   if (file)
-    fprintf (stderr, "%s:%u: ", file, line);
+    {
+      if (line != 0)
+	fprintf (stderr, "%s:%u: ", file, line);
+      else
+	fprintf (stderr, "%s: ", file);
+    }
 }
 
 /* Send to stderr a string as a warning, and locate warning
@@ -137,19 +151,23 @@ as_tsktsk (const char *format, ...)
 /* The common portion of as_warn and as_warn_where.  */
 
 static void
-as_warn_internal (char *file, unsigned int line, char *buffer)
+as_warn_internal (const char *file, unsigned int line, char *buffer)
 {
   ++warning_count;
 
   if (file == NULL)
-    as_where (&file, &line);
+    file = as_where (&line);
 
   identify (file);
   if (file)
-    fprintf (stderr, "%s:%u: ", file, line);
-  fprintf (stderr, _("Warning: "));
-  fputs (buffer, stderr);
-  (void) putc ('\n', stderr);
+    {
+      if (line != 0)
+	fprintf (stderr, "%s:%u: %s%s\n", file, line, _("Warning: "), buffer);
+      else
+	fprintf (stderr, "%s: %s%s\n", file, _("Warning: "), buffer);
+    }
+  else
+    fprintf (stderr, "%s%s\n", _("Warning: "), buffer);
 #ifndef NO_LISTING
   listing_warning (buffer);
 #endif
@@ -181,7 +199,7 @@ as_warn (const char *format, ...)
    the varargs correctly and portably.  */
 
 void
-as_warn_where (char *file, unsigned int line, const char *format, ...)
+as_warn_where (const char *file, unsigned int line, const char *format, ...)
 {
   va_list args;
   char buffer[2000];
@@ -198,26 +216,30 @@ as_warn_where (char *file, unsigned int line, const char *format, ...)
 /* The common portion of as_bad and as_bad_where.  */
 
 static void
-as_bad_internal (char *file, unsigned int line, char *buffer)
+as_bad_internal (const char *file, unsigned int line, char *buffer)
 {
   ++error_count;
 
   if (file == NULL)
-    as_where (&file, &line);
+    file = as_where (&line);
 
   identify (file);
   if (file)
-    fprintf (stderr, "%s:%u: ", file, line);
-  fprintf (stderr, _("Error: "));
-  fputs (buffer, stderr);
-  (void) putc ('\n', stderr);
+    {
+      if (line != 0)
+	fprintf (stderr, "%s:%u: %s%s\n", file, line, _("Error: "), buffer);
+      else
+	fprintf (stderr, "%s: %s%s\n", file, _("Error: "), buffer);
+    }
+  else
+    fprintf (stderr, "%s%s\n", _("Error: "), buffer);
 #ifndef NO_LISTING
   listing_error (buffer);
 #endif
 }
 
 /* Send to stderr a string as a warning, and locate warning in input
-   file(s).  Please us when there is no recovery, but we want to
+   file(s).  Please use when there is no recovery, but we want to
    continue processing but not produce an object file.
    Please explain in string (which may have '\n's) what recovery was
    done.  */
@@ -240,7 +262,7 @@ as_bad (const char *format, ...)
    the varargs correctly and portably.  */
 
 void
-as_bad_where (char *file, unsigned int line, const char *format, ...)
+as_bad_where (const char *file, unsigned int line, const char *format, ...)
 {
   va_list args;
   char buffer[2000];
@@ -275,40 +297,63 @@ as_fatal (const char *format, ...)
   xexit (EXIT_FAILURE);
 }
 
-/* Indicate assertion failure.
-   Arguments: Filename, line number, optional function name.  */
-
-void
-as_assert (const char *file, int line, const char *fn)
-{
-  as_show_where ();
-  fprintf (stderr, _("Internal error!\n"));
-  if (fn)
-    fprintf (stderr, _("Assertion failure in %s at %s line %d.\n"),
-	     fn, file, line);
-  else
-    fprintf (stderr, _("Assertion failure at %s line %d.\n"), file, line);
-  fprintf (stderr, _("Please report this bug.\n"));
-  xexit (EXIT_FAILURE);
-}
-
-/* as_abort: Print a friendly message saying how totally hosed we are,
-   and exit without producing a core file.  */
+/* Indicate internal constency error.
+   Arguments: Filename, line number, optional function name.
+   FILENAME may be NULL, which we use for crash-via-signal.  */
 
 void
 as_abort (const char *file, int line, const char *fn)
 {
   as_show_where ();
-  if (fn)
-    fprintf (stderr, _("Internal error, aborting at %s line %d in %s\n"),
-	     file, line, fn);
+
+  if (!file)
+    fprintf (stderr, _("Internal error (%s).\n"), fn ? fn : "unknown");
+  else if (fn)
+    fprintf (stderr, _("Internal error in %s at %s:%d.\n"), fn, file, line);
   else
-    fprintf (stderr, _("Internal error, aborting at %s line %d\n"),
-	     file, line);
+    fprintf (stderr, _("Internal error at %s:%d.\n"), file, line);
+
   fprintf (stderr, _("Please report this bug.\n"));
+
   xexit (EXIT_FAILURE);
 }
 
+/* Handler for fatal signals, such as SIGSEGV. */
+
+static void
+signal_crash (int signo)
+{
+  /* Reset, to prevent unbounded recursion.  */
+  signal (signo, SIG_DFL);
+
+  as_abort (NULL, 0, strsignal (signo));
+}
+
+/* Register signal handlers, for less abrubt crashes.  */
+
+void
+signal_init (void)
+{
+#ifdef SIGSEGV
+  signal (SIGSEGV, signal_crash);
+#endif
+#ifdef SIGILL
+  signal (SIGILL, signal_crash);
+#endif
+#ifdef SIGBUS
+  signal (SIGBUS, signal_crash);
+#endif
+#ifdef SIGABRT
+  signal (SIGABRT, signal_crash);
+#endif
+#if defined SIGIOT && (!defined SIGABRT || SIGABRT != SIGIOT)
+  signal (SIGIOT, signal_crash);
+#endif
+#ifdef SIGFPE
+  signal (SIGFPE, signal_crash);
+#endif
+}
+
 /* Support routines.  */
 
 void
@@ -331,13 +376,13 @@ sprint_value (char *buf, valueT val)
 #define HEX_MIN_THRESHOLD	-(HEX_MAX_THRESHOLD)
 
 static void
-as_internal_value_out_of_range (char *    prefix,
-				offsetT   val,
-				offsetT   min,
-				offsetT   max,
-				char *    file,
-				unsigned  line,
-				int       bad)
+as_internal_value_out_of_range (const char *prefix,
+				offsetT val,
+				offsetT min,
+				offsetT max,
+				const char *file,
+				unsigned line,
+				int bad)
 {
   const char * err;
 
@@ -403,22 +448,22 @@ as_internal_value_out_of_range (char *    prefix,
 }
 
 void
-as_warn_value_out_of_range (char *   prefix,
-			   offsetT  value,
-			   offsetT  min,
-			   offsetT  max,
-			   char *   file,
+as_warn_value_out_of_range (const char *prefix,
+			   offsetT value,
+			   offsetT min,
+			   offsetT max,
+			   const char *file,
 			   unsigned line)
 {
   as_internal_value_out_of_range (prefix, value, min, max, file, line, 0);
 }
 
 void
-as_bad_value_out_of_range (char *   prefix,
-			   offsetT  value,
-			   offsetT  min,
-			   offsetT  max,
-			   char *   file,
+as_bad_value_out_of_range (const char *prefix,
+			   offsetT value,
+			   offsetT min,
+			   offsetT max,
+			   const char *file,
 			   unsigned line)
 {
   as_internal_value_out_of_range (prefix, value, min, max, file, line, 1);
