@@ -10,3 +10,11 @@ TEXT_LENGTH=128K
 DATA_ORIGIN=0x800060
 DATA_LENGTH=0xffa0
 EXTRA_EM_FILE=avrelf
+
+FUSE_NAME=fuse
+
+EEPROM_LENGTH=64K
+FUSE_LENGTH=1K
+LOCK_LENGTH=1K
+SIGNATURE_LENGTH=1K
+USER_SIGNATURE_LENGTH=1K
