@@ -263,6 +263,8 @@ static initializer cpu_flag_init[] =
     "CpuRDPID" },
   { "CPU_PTWRITE_FLAGS",
     "CpuPTWRITE" },
+  { "CPU_CET_FLAGS",
+    "CpuCET" },
   { "CPU_ANY_X87_FLAGS",
     "CPU_ANY_287_FLAGS|Cpu8087" },
   { "CPU_ANY_287_FLAGS",
@@ -524,6 +526,7 @@ static bitfield cpu_flags[] =
   BITFIELD (CpuOSPKE),
   BITFIELD (CpuRDPID),
   BITFIELD (CpuPTWRITE),
+  BITFIELD (CpuCET),
   BITFIELD (CpuRegMMX),
   BITFIELD (CpuRegXMM),
   BITFIELD (CpuRegYMM),
@@ -538,7 +541,7 @@ static bitfield opcode_modifiers[] =
 {
   BITFIELD (D),
   BITFIELD (W),
-  BITFIELD (S),
+  BITFIELD (Load),
   BITFIELD (Modrm),
   BITFIELD (ShortForm),
   BITFIELD (Jump),
@@ -563,6 +566,7 @@ static bitfield opcode_modifiers[] =
   BITFIELD (FWait),
   BITFIELD (IsString),
   BITFIELD (BNDPrefixOk),
+  BITFIELD (NoTrackPrefixOk),
   BITFIELD (IsLockable),
   BITFIELD (RegKludge),
   BITFIELD (FirstXmm0),
